@@ -1,27 +1,34 @@
 # -*- coding: utf-8 -*-
+# BSD 3-Clause License
 #
-# Copyright (C) 2020 Chris Caron <lead2gold@gmail.com>
-# All rights reserved.
+# Apprise - Push Notification Library.
+# Copyright (c) 2023, Chris Caron <lead2gold@gmail.com>
 #
-# This code is licensed under the MIT License.
+# Redistribution and use in source and binary forms, with or without
+# modification, are permitted provided that the following conditions are met:
 #
-# Permission is hereby granted, free of charge, to any person obtaining a copy
-# of this software and associated documentation files(the "Software"), to deal
-# in the Software without restriction, including without limitation the rights
-# to use, copy, modify, merge, publish, distribute, sublicense, and / or sell
-# copies of the Software, and to permit persons to whom the Software is
-# furnished to do so, subject to the following conditions :
+# 1. Redistributions of source code must retain the above copyright notice,
+#    this list of conditions and the following disclaimer.
 #
-# The above copyright notice and this permission notice shall be included in
-# all copies or substantial portions of the Software.
+# 2. Redistributions in binary form must reproduce the above copyright notice,
+#    this list of conditions and the following disclaimer in the documentation
+#    and/or other materials provided with the distribution.
 #
-# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.IN NO EVENT SHALL THE
-# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
-# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
-# THE SOFTWARE.
+# 3. Neither the name of the copyright holder nor the names of its
+#    contributors may be used to endorse or promote products derived from
+#    this software without specific prior written permission.
+#
+# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
+# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+# ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
+# LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
+# CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
+# SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
+# INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
+# CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
+# ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
+# POSSIBILITY OF SUCH DAMAGE.
 
 from __future__ import absolute_import
 from __future__ import print_function
@@ -121,9 +128,13 @@ class NotifyMacOSX(NotifyBase):
             'name': _('Sound'),
             'type': 'string',
         },
+        'click': {
+            'name': _('Open/Click URL'),
+            'type': 'string',
+        },
     })
 
-    def __init__(self, sound=None, include_image=True, **kwargs):
+    def __init__(self, sound=None, include_image=True, click=None, **kwargs):
         """
         Initialize MacOSX Object
         """
@@ -137,6 +148,10 @@ class NotifyMacOSX(NotifyBase):
         self.notify_path = next(  # pragma: no branch
             (p for p in self.notify_paths if os.access(p, os.X_OK)), None)
 
+        # Click URL
+        # Allow user to provide the `--open` argument on the notify wrapper
+        self.click = click
+
         # Set sound object (no q/a for now)
         self.sound = sound
 
@@ -162,6 +177,9 @@ class NotifyMacOSX(NotifyBase):
         if title:
             cmd.extend(['-title', title])
 
+        if self.click:
+            cmd.extend(['-open', self.click])
+
         # The sound to play
         if self.sound:
             cmd.extend(['-sound', self.sound])
@@ -179,8 +197,7 @@ class NotifyMacOSX(NotifyBase):
         self.logger.debug('MacOSX CMD: {}'.format(' '.join(cmd)))
 
         # Send our notification
-        output = subprocess.Popen(
-            cmd, stdout=subprocess.PIPE, stderr=subprocess.STDOUT)
+        output = subprocess.Popen(cmd)
 
         # Wait for process to complete
         output.wait()
@@ -203,6 +220,9 @@ class NotifyMacOSX(NotifyBase):
             'image': 'yes' if self.include_image else 'no',
         }
 
+        if self.click:
+            params['click'] = self.click
+
         # Extend our parameters
         params.update(self.url_parameters(privacy=privacy, *args, **kwargs))
 
@@ -230,6 +250,10 @@ class NotifyMacOSX(NotifyBase):
         results['include_image'] = \
             parse_bool(results['qsd'].get('image', True))
 
+        # Support 'click'
+        if 'click' in results['qsd'] and len(results['qsd']['click']):
+            results['click'] = NotifyMacOSX.unquote(results['qsd']['click'])
+
         # Support 'sound'
         if 'sound' in results['qsd'] and len(results['qsd']['sound']):
             results['sound'] = NotifyMacOSX.unquote(results['qsd']['sound'])
