@@ -121,6 +121,9 @@ class NotifyMailgun(NotifyBase):
     # A URL that takes you to the setup/help of the specific protocol
     setup_url = 'https://github.com/caronc/apprise/wiki/Notify_mailgun'
 
+    # Support attachments
+    attachment_support = True
+
     # Default Notify Format
     notify_format = NotifyFormat.HTML
 
@@ -371,7 +374,7 @@ class NotifyMailgun(NotifyBase):
         # Track our potential files
         files = {}
 
-        if attach:
+        if attach and self.attachment_support:
             for idx, attachment in enumerate(attach):
                 # Perform some simple error checking
                 if not attachment:
