@@ -75,6 +75,9 @@ class NotifyPushBullet(NotifyBase):
     # PushBullet uses the http protocol with JSON requests
     notify_url = 'https://api.pushbullet.com/v2/{}'
 
+    # Support attachments
+    attachment_support = True
+
     # Define object templates
     templates = (
         '{schema}://{accesstoken}',
@@ -150,7 +153,7 @@ class NotifyPushBullet(NotifyBase):
         # Build a list of our attachments
         attachments = []
 
-        if attach:
+        if attach and self.attachment_support:
             # We need to upload our payload first so that we can source it
             # in remaining messages
             for attachment in attach:
@@ -261,14 +264,15 @@ class NotifyPushBullet(NotifyBase):
                     "PushBullet recipient {} parsed as a device"
                     .format(recipient))
 
-            okay, response = self._send(
-                self.notify_url.format('pushes'), payload)
-            if not okay:
-                has_error = True
-                continue
+            if body:
+                okay, response = self._send(
+                    self.notify_url.format('pushes'), payload)
+                if not okay:
+                    has_error = True
+                    continue
 
-            self.logger.info(
-                'Sent PushBullet notification to "%s".' % (recipient))
+                self.logger.info(
+                    'Sent PushBullet notification to "%s".' % (recipient))
 
             for attach_payload in attachments:
                 # Send our attachments to our same user (already prepared as
