@@ -336,6 +336,9 @@ class NotifyPushSafer(NotifyBase):
     # The default secure protocol
     secure_protocol = 'psafers'
 
+    # Support attachments
+    attachment_support = True
+
     # Number of requests to a allow per second
     request_rate_per_sec = 1.2
 
@@ -546,7 +549,7 @@ class NotifyPushSafer(NotifyBase):
         # Initialize our list of attachments
         attachments = []
 
-        if attach:
+        if attach and self.attachment_support:
             # We need to upload our payload first so that we can source it
             # in remaining messages
             for attachment in attach:
