@@ -143,6 +143,10 @@ class NotifySlack(NotifyBase):
     # A URL that takes you to the setup/help of the specific protocol
     setup_url = 'https://github.com/caronc/apprise/wiki/Notify_slack'
 
+    # Support attachments
+    attachment_support = True
+
+    # The maximum targets to include when doing batch transfers
     # Slack Webhook URL
     webhook_url = 'https://hooks.slack.com/services'
 
@@ -522,7 +526,8 @@ class NotifySlack(NotifyBase):
                 # Include the footer only if specified to do so
                 payload['attachments'][0]['footer'] = self.app_id
 
-        if attach and self.mode is SlackMode.WEBHOOK:
+        if attach and self.attachment_support \
+                and self.mode is SlackMode.WEBHOOK:
             # Be friendly; let the user know why they can't send their
             # attachments if using the Webhook mode
             self.logger.warning(
@@ -600,7 +605,8 @@ class NotifySlack(NotifyBase):
                     ' to {}'.format(channel)
                     if channel is not None else ''))
 
-        if attach and self.mode is SlackMode.BOT and attach_channel_list:
+        if attach and self.attachment_support and \
+                self.mode is SlackMode.BOT and attach_channel_list:
             # Send our attachments (can only be done in bot mode)
             for attachment in attach:
 
