@@ -79,6 +79,9 @@ class NotifyXML(NotifyBase):
     # A URL that takes you to the setup/help of the specific protocol
     setup_url = 'https://github.com/caronc/apprise/wiki/Notify_Custom_XML'
 
+    # Support attachments
+    attachment_support = True
+
     # Allows the user to specify the NotifyImageSize object
     image_size = NotifyImageSize.XY_128
 
@@ -340,7 +343,7 @@ class NotifyXML(NotifyBase):
             ['<{}>{}</{}>'.format(k, v, k) for k, v in payload_base.items()])
 
         attachments = []
-        if attach:
+        if attach and self.attachment_support:
             for attachment in attach:
                 # Perform some simple error checking
                 if not attachment:
