@@ -187,12 +187,12 @@ class AppriseURLTester:
         if instance is None:
             # Expected None but didn't get it
             print('%s instantiated %s (but expected None)' % (
-                url, str(obj)))
+                url, type(obj)))
             assert False
 
         if not isinstance(obj, instance):
             print('%s instantiated %s (but expected %s)' % (
-                url, type(instance), str(obj)))
+                url, type(instance), type(obj)))
             assert False
 
         if isinstance(obj, NotifyBase):
@@ -332,9 +332,14 @@ class AppriseURLTester:
             requests_response_text = dumps(requests_response_text)
             requests_response_content = requests_response_text.encode('utf-8')
 
+        else:
+            requests_response_content = u''
+            requests_response_text = ''
+
         # A request
         robj = mock.Mock()
         robj.content = u''
+        robj.text = ''
         mock_get.return_value = robj
         mock_post.return_value = robj
         mock_head.return_value = robj
@@ -472,6 +477,52 @@ class AppriseURLTester:
                         notify_type=notify_type,
                         attach=attach) == attach_response
 
+                    if obj.attachment_support:
+                        #
+                        # Services that support attachments should support
+                        # sending a attachment (or more) without a body or
+                        # title specified:
+                        #
+                        assert obj.notify(
+                            body=None, title=None,
+                            notify_type=notify_type,
+                            attach=attach) == attach_response
+
+                        # Turn off attachment support on the notifications
+                        # that support it so we can test that any logic we
+                        # have ot test against this flag is ran
+                        obj.attachment_support = False
+
+                        #
+                        # Notifications should still transmit as normal if
+                        # Attachment support is flipped off
+                        #
+                        assert obj.notify(
+                            body=self.body, title=self.title,
+                            notify_type=notify_type,
+                            attach=attach) == notify_response
+
+                        #
+                        # We should not be able to send a message without a
+                        # body or title in this circumstance
+                        #
+                        assert obj.notify(
+                            body=None, title=None,
+                            notify_type=notify_type,
+                            attach=attach) is False
+
+                        # Toggle Back
+                        obj.attachment_support = True
+
+                    else:  # No Attachment support
+                        #
+                        # We should not be able to send a message without a
+                        # body or title in this circumstance
+                        #
+                        assert obj.notify(
+                            body=None, title=None,
+                            notify_type=notify_type,
+                            attach=attach) is False
             else:
 
                 for _exception in self.req_exceptions:
