@@ -53,6 +53,7 @@ from apprise import __version__
 from apprise import URLBase
 from apprise import PrivacyMode
 from apprise.AppriseLocale import LazyTranslation
+from apprise.AppriseLocale import gettext_lazy as _
 
 from apprise import common
 from apprise.plugins import __load_matrix
@@ -257,9 +258,11 @@ def apprise_test(do_notify):
     assert do_notify(a, title=object(), body=b'bytes') is False
     assert do_notify(a, title=b"bytes", body=object()) is False
 
-    # As long as one is present, we're good
+    # A Body must be present
+    assert do_notify(a, title='present', body=None) is False
+
+    # Other combinations work fine
     assert do_notify(a, title=None, body='present') is True
-    assert do_notify(a, title='present', body=None) is True
     assert do_notify(a, title="present", body="present") is True
 
     # Send Attachment with success
@@ -1377,7 +1380,8 @@ def test_apprise_details():
         assert 'details' in entry['requirements']
         assert 'packages_required' in entry['requirements']
         assert 'packages_recommended' in entry['requirements']
-        assert isinstance(entry['requirements']['details'], str)
+        assert isinstance(entry['requirements']['details'], (
+            str, LazyTranslation))
         assert isinstance(entry['requirements']['packages_required'], list)
         assert isinstance(entry['requirements']['packages_recommended'], list)
 
@@ -1404,7 +1408,8 @@ def test_apprise_details():
         assert 'details' in entry['requirements']
         assert 'packages_required' in entry['requirements']
         assert 'packages_recommended' in entry['requirements']
-        assert isinstance(entry['requirements']['details'], str)
+        assert isinstance(entry['requirements']['details'], (
+            str, LazyTranslation))
         assert isinstance(entry['requirements']['packages_required'], list)
         assert isinstance(entry['requirements']['packages_recommended'], list)
 
