@@ -1,27 +1,34 @@
 # -*- coding: utf-8 -*-
+# BSD 3-Clause License
 #
-# Copyright (C) 2020 Chris Caron <lead2gold@gmail.com>
-# All rights reserved.
+# Apprise - Push Notification Library.
+# Copyright (c) 2023, Chris Caron <lead2gold@gmail.com>
 #
-# This code is licensed under the MIT License.
+# Redistribution and use in source and binary forms, with or without
+# modification, are permitted provided that the following conditions are met:
 #
-# Permission is hereby granted, free of charge, to any person obtaining a copy
-# of this software and associated documentation files(the "Software"), to deal
-# in the Software without restriction, including without limitation the rights
-# to use, copy, modify, merge, publish, distribute, sublicense, and / or sell
-# copies of the Software, and to permit persons to whom the Software is
-# furnished to do so, subject to the following conditions :
+# 1. Redistributions of source code must retain the above copyright notice,
+#    this list of conditions and the following disclaimer.
 #
-# The above copyright notice and this permission notice shall be included in
-# all copies or substantial portions of the Software.
+# 2. Redistributions in binary form must reproduce the above copyright notice,
+#    this list of conditions and the following disclaimer in the documentation
+#    and/or other materials provided with the distribution.
 #
-# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.IN NO EVENT SHALL THE
-# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
-# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
-# THE SOFTWARE.
+# 3. Neither the name of the copyright holder nor the names of its
+#    contributors may be used to endorse or promote products derived from
+#    this software without specific prior written permission.
+#
+# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
+# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+# ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
+# LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
+# CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
+# SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
+# INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
+# CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
+# ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
+# POSSIBILITY OF SUCH DAMAGE.
 
 import pytest
 from apprise.AppriseAsset import AppriseAsset
@@ -325,7 +332,7 @@ def test_config_base_config_parse_text():
     assert isinstance(result, list)
     assert len(result) == 0
 
-    # There was 1 valid entry
+    # There were no include entries defined
     assert len(config) == 0
 
     # Test case where a comment is on it's own line with nothing else
@@ -337,6 +344,56 @@ def test_config_base_config_parse_text():
     # There were no include entries defined
     assert len(config) == 0
 
+    # Verify our tagging works when multiple tags are provided
+    result, config = ConfigBase.config_parse_text("""
+    tag1, tag2, tag3=json://user:pass@localhost
+    """)
+
+    assert isinstance(result, list)
+    assert len(result) == 1
+    assert len(result[0].tags) == 3
+    assert 'tag1' in result[0].tags
+    assert 'tag2' in result[0].tags
+    assert 'tag3' in result[0].tags
+
+
+def test_config_base_config_parse_text_with_url():
+    """
+    API: ConfigBase.config_parse_text object_with_url
+
+    """
+    # Here is a similar result set however this one has an invalid line
+    # in it which invalidates the entire file
+    result, config = ConfigBase.config_parse_text("""
+    # Test a URL that has a URL as an argument
+    json://user:pass@localhost?+arg=http://example.com?arg2=1&arg3=3
+    """)
+
+    # No tag is parsed, but our URL successfully parses as is
+
+    assert isinstance(result, list)
+    assert len(result) == 1
+    assert len(result[0].tags) == 0
+
+    # Verify our URL is correctly captured
+    assert '%2Barg=http%3A%2F%2Fexample.com%3Farg2%3D1' in result[0].url()
+    assert 'json://user:pass@localhost/' in result[0].url()
+
+    # There were no include entries defined
+    assert len(config) == 0
+
+    # Pass in our configuration again
+    result, config = ConfigBase.config_parse_text(result[0].url())
+
+    # Verify that our results repeat themselves
+    assert isinstance(result, list)
+    assert len(result) == 1
+    assert len(result[0].tags) == 0
+    assert '%2Barg=http%3A%2F%2Fexample.com%3Farg2%3D1' in result[0].url()
+    assert 'json://user:pass@localhost/' in result[0].url()
+
+    assert len(config) == 0
+
 
 def test_config_base_config_parse_yaml():
     """
