@@ -1,28 +1,36 @@
 # -*- coding: utf-8 -*-
+# BSD 3-Clause License
 #
-# Copyright (C) 2020 Chris Caron <lead2gold@gmail.com>
-# All rights reserved.
+# Apprise - Push Notification Library.
+# Copyright (c) 2023, Chris Caron <lead2gold@gmail.com>
 #
-# This code is licensed under the MIT License.
+# Redistribution and use in source and binary forms, with or without
+# modification, are permitted provided that the following conditions are met:
 #
-# Permission is hereby granted, free of charge, to any person obtaining a copy
-# of this software and associated documentation files(the "Software"), to deal
-# in the Software without restriction, including without limitation the rights
-# to use, copy, modify, merge, publish, distribute, sublicense, and / or sell
-# copies of the Software, and to permit persons to whom the Software is
-# furnished to do so, subject to the following conditions :
+# 1. Redistributions of source code must retain the above copyright notice,
+#    this list of conditions and the following disclaimer.
 #
-# The above copyright notice and this permission notice shall be included in
-# all copies or substantial portions of the Software.
+# 2. Redistributions in binary form must reproduce the above copyright notice,
+#    this list of conditions and the following disclaimer in the documentation
+#    and/or other materials provided with the distribution.
 #
-# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.IN NO EVENT SHALL THE
-# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
-# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
-# THE SOFTWARE.
+# 3. Neither the name of the copyright holder nor the names of its
+#    contributors may be used to endorse or promote products derived from
+#    this software without specific prior written permission.
+#
+# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
+# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+# ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
+# LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
+# CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
+# SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
+# INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
+# CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
+# ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
+# POSSIBILITY OF SUCH DAMAGE.
 
+import logging
 import os
 import re
 from unittest import mock
@@ -34,15 +42,13 @@ from apprise import NotifyType, NotifyBase
 from apprise import Apprise
 from apprise import AttachBase
 from apprise import AppriseAttachment
-from apprise.plugins import NotifyEmailBase
+from apprise.plugins.NotifyEmail import NotifyEmail
+from apprise.plugins import NotifyEmail as NotifyEmailModule
 
 # Disable logging for a cleaner testing output
-import logging
-
-from apprise.plugins.NotifyEmail import NotifyEmail
-
 logging.disable(logging.CRITICAL)
 
+
 # Attachment Directory
 TEST_VAR_DIR = os.path.join(os.path.dirname(__file__), 'var')
 
@@ -106,6 +112,12 @@ TEST_URLS = (
     ('mailtos://user:pass@nuxref.com:567', {
         'instance': NotifyEmail,
     }),
+    ('mailto://user:pass@nuxref.com?mode=ssl', {
+        # mailto:// with mode=ssl causes us to convert to ssl
+        'instance': NotifyEmail,
+        # Our expected url(privacy=True) startswith() response:
+        'privacy_url': 'mailtos://user:****@nuxref.com',
+    }),
     ('mailto://user:pass@nuxref.com:567?format=html', {
         'instance': NotifyEmail,
     }),
@@ -330,6 +342,9 @@ def test_plugin_email(mock_smtp, mock_smtpssl):
                 # We loaded okay; now lets make sure we can reverse this url
                 assert isinstance(obj.url(), str) is True
 
+                # Verify we can acquire a target count as an integer
+                assert isinstance(len(obj), int)
+
                 # Test url() with privacy=True
                 assert isinstance(
                     obj.url(privacy=True), str) is True
@@ -357,6 +372,14 @@ def test_plugin_email(mock_smtp, mock_smtpssl):
                         url, obj.url()))
                     assert False
 
+                # Verify there is no change from the old and the new
+                if len(obj) != len(obj_cmp):
+                    print('%d targets found in %s' % (
+                        len(obj), obj.url(privacy=True)))
+                    print('But %d targets found in %s' % (
+                        len(obj_cmp), obj_cmp.url(privacy=True)))
+                    raise AssertionError("Target miscount %d != %d")
+
             if self:
                 # Iterate over our expected entries inside of our object
                 for key, val in self.items():
@@ -366,11 +389,19 @@ def test_plugin_email(mock_smtp, mock_smtpssl):
 
             try:
                 if test_smtplib_exceptions is False:
+                    # Verify we can acquire a target count as an integer
+                    targets = len(obj)
+
                     # check that we're as expected
                     assert obj.notify(
                         title='test', body='body',
                         notify_type=NotifyType.INFO) == response
 
+                    if response:
+                        # If we successfully got a response, there must have
+                        # been at least 1 target present
+                        assert targets > 0
+
                 else:
                     for exception in test_smtplib_exceptions:
                         mock_socket.sendmail.side_effect = exception
@@ -420,7 +451,7 @@ def test_plugin_email_webbase_lookup(mock_smtp, mock_smtpssl):
     """
 
     # Insert a test email at the head of our table
-    NotifyEmailBase.EMAIL_TEMPLATES = (
+    NotifyEmailModule.EMAIL_TEMPLATES = (
         (
             # Testing URL
             'Testing Lookup',
@@ -429,10 +460,10 @@ def test_plugin_email_webbase_lookup(mock_smtp, mock_smtpssl):
                 'port': 123,
                 'smtp_host': 'smtp.l2g.com',
                 'secure': True,
-                'login_type': (NotifyEmailBase.WebBaseLogin.USERID, )
+                'login_type': (NotifyEmailModule.WebBaseLogin.USERID, )
             },
         ),
-    ) + NotifyEmailBase.EMAIL_TEMPLATES
+    ) + NotifyEmailModule.EMAIL_TEMPLATES
 
     obj = Apprise.instantiate(
         'mailto://user:pass@l2g.com', suppress_exceptions=True)
@@ -914,6 +945,7 @@ def test_plugin_email_url_parsing(mock_smtp, mock_smtp_ssl):
     assert 'smtp=smtp-mail.outlook.com' in obj.url()
 
     mock_smtp.reset_mock()
+    mock_smtp_ssl.reset_mock()
     response.reset_mock()
 
     # The below switches the `name` with the `to` to verify the results
@@ -953,6 +985,11 @@ def test_plugin_email_url_parsing(mock_smtp, mock_smtp_ssl):
     assert _to[0] == 'user2@yahoo.com'
     assert _msg.split('\n')[-3] == 'test'
 
+    user, pw = response.login.call_args[0]
+    # the SMTP Server was ovr
+    assert pw == 'pass123'
+    assert user == 'user'
+
     assert obj.url().startswith(
         'mailtos://user:pass123@hotmail.com/user2%40yahoo.com')
     # Test that our template over-ride worked
@@ -962,11 +999,38 @@ def test_plugin_email_url_parsing(mock_smtp, mock_smtp_ssl):
     assert 'reply=' not in obj.url()
 
     mock_smtp.reset_mock()
+    mock_smtp_ssl.reset_mock()
     response.reset_mock()
 
     #
     # Test outlook/hotmail lookups
     #
+    results = NotifyEmail.parse_url(
+        'mailtos://user:pass123@hotmail.com')
+    obj = Apprise.instantiate(results, suppress_exceptions=False)
+    assert isinstance(obj, NotifyEmail) is True
+    assert obj.smtp_host == 'smtp-mail.outlook.com'
+    # No entries in the reply_to
+    assert not obj.reply_to
+
+    assert mock_smtp.call_count == 0
+    assert mock_smtp_ssl.call_count == 0
+    assert response.starttls.call_count == 0
+    assert obj.notify("test") is True
+    assert mock_smtp.call_count == 1
+    assert mock_smtp_ssl.call_count == 0
+    assert response.starttls.call_count == 1
+    assert response.login.call_count == 1
+    assert response.sendmail.call_count == 1
+
+    user, pw = response.login.call_args[0]
+    assert pw == 'pass123'
+    assert user == 'user@hotmail.com'
+
+    mock_smtp.reset_mock()
+    mock_smtp_ssl.reset_mock()
+    response.reset_mock()
+
     results = NotifyEmail.parse_url(
         'mailtos://user:pass123@outlook.com')
     obj = Apprise.instantiate(results, suppress_exceptions=False)
@@ -975,6 +1039,24 @@ def test_plugin_email_url_parsing(mock_smtp, mock_smtp_ssl):
     # No entries in the reply_to
     assert not obj.reply_to
 
+    assert mock_smtp.call_count == 0
+    assert mock_smtp_ssl.call_count == 0
+    assert response.starttls.call_count == 0
+    assert obj.notify("test") is True
+    assert mock_smtp.call_count == 1
+    assert mock_smtp_ssl.call_count == 0
+    assert response.starttls.call_count == 1
+    assert response.login.call_count == 1
+    assert response.sendmail.call_count == 1
+
+    user, pw = response.login.call_args[0]
+    assert pw == 'pass123'
+    assert user == 'user@outlook.com'
+
+    mock_smtp.reset_mock()
+    mock_smtp_ssl.reset_mock()
+    response.reset_mock()
+
     results = NotifyEmail.parse_url(
         'mailtos://user:pass123@outlook.com.au')
     obj = Apprise.instantiate(results, suppress_exceptions=False)
@@ -983,6 +1065,24 @@ def test_plugin_email_url_parsing(mock_smtp, mock_smtp_ssl):
     # No entries in the reply_to
     assert not obj.reply_to
 
+    assert mock_smtp.call_count == 0
+    assert mock_smtp_ssl.call_count == 0
+    assert response.starttls.call_count == 0
+    assert obj.notify("test") is True
+    assert mock_smtp.call_count == 1
+    assert mock_smtp_ssl.call_count == 0
+    assert response.starttls.call_count == 1
+    assert response.login.call_count == 1
+    assert response.sendmail.call_count == 1
+
+    user, pw = response.login.call_args[0]
+    assert pw == 'pass123'
+    assert user == 'user@outlook.com.au'
+
+    mock_smtp.reset_mock()
+    mock_smtp_ssl.reset_mock()
+    response.reset_mock()
+
     # Consisitency Checks
     results = NotifyEmail.parse_url(
         'mailtos://outlook.com?smtp=smtp.outlook.com'
@@ -995,6 +1095,24 @@ def test_plugin_email_url_parsing(mock_smtp, mock_smtp_ssl):
     assert obj1.secure_mode == 'starttls'
     assert obj1.port == 587
 
+    assert mock_smtp.call_count == 0
+    assert mock_smtp_ssl.call_count == 0
+    assert response.starttls.call_count == 0
+    assert obj1.notify("test") is True
+    assert mock_smtp.call_count == 1
+    assert mock_smtp_ssl.call_count == 0
+    assert response.starttls.call_count == 1
+    assert response.login.call_count == 1
+    assert response.sendmail.call_count == 1
+
+    user, pw = response.login.call_args[0]
+    assert pw == 'app.pw'
+    assert user == 'user@outlook.com'
+
+    mock_smtp.reset_mock()
+    mock_smtp_ssl.reset_mock()
+    response.reset_mock()
+
     results = NotifyEmail.parse_url(
         'mailtos://user:app.pw@outlook.com')
     obj2 = Apprise.instantiate(results, suppress_exceptions=False)
@@ -1005,6 +1123,24 @@ def test_plugin_email_url_parsing(mock_smtp, mock_smtp_ssl):
     assert obj2.secure_mode == obj1.secure_mode
     assert obj2.port == obj1.port
 
+    assert mock_smtp.call_count == 0
+    assert mock_smtp_ssl.call_count == 0
+    assert response.starttls.call_count == 0
+    assert obj2.notify("test") is True
+    assert mock_smtp.call_count == 1
+    assert mock_smtp_ssl.call_count == 0
+    assert response.starttls.call_count == 1
+    assert response.login.call_count == 1
+    assert response.sendmail.call_count == 1
+
+    user, pw = response.login.call_args[0]
+    assert pw == 'app.pw'
+    assert user == 'user@outlook.com'
+
+    mock_smtp.reset_mock()
+    mock_smtp_ssl.reset_mock()
+    response.reset_mock()
+
     results = NotifyEmail.parse_url(
         'mailtos://user:pass123@live.com')
     obj = Apprise.instantiate(results, suppress_exceptions=False)
@@ -1012,6 +1148,24 @@ def test_plugin_email_url_parsing(mock_smtp, mock_smtp_ssl):
     # No entries in the reply_to
     assert not obj.reply_to
 
+    assert mock_smtp.call_count == 0
+    assert mock_smtp_ssl.call_count == 0
+    assert response.starttls.call_count == 0
+    assert obj.notify("test") is True
+    assert mock_smtp.call_count == 1
+    assert mock_smtp_ssl.call_count == 0
+    assert response.starttls.call_count == 1
+    assert response.login.call_count == 1
+    assert response.sendmail.call_count == 1
+
+    user, pw = response.login.call_args[0]
+    assert pw == 'pass123'
+    assert user == 'user@live.com'
+
+    mock_smtp.reset_mock()
+    mock_smtp_ssl.reset_mock()
+    response.reset_mock()
+
     results = NotifyEmail.parse_url(
         'mailtos://user:pass123@hotmail.com')
     obj = Apprise.instantiate(results, suppress_exceptions=False)
@@ -1019,6 +1173,24 @@ def test_plugin_email_url_parsing(mock_smtp, mock_smtp_ssl):
     # No entries in the reply_to
     assert not obj.reply_to
 
+    assert mock_smtp.call_count == 0
+    assert mock_smtp_ssl.call_count == 0
+    assert response.starttls.call_count == 0
+    assert obj.notify("test") is True
+    assert mock_smtp.call_count == 1
+    assert mock_smtp_ssl.call_count == 0
+    assert response.starttls.call_count == 1
+    assert response.login.call_count == 1
+    assert response.sendmail.call_count == 1
+
+    user, pw = response.login.call_args[0]
+    assert pw == 'pass123'
+    assert user == 'user@hotmail.com'
+
+    mock_smtp.reset_mock()
+    mock_smtp_ssl.reset_mock()
+    response.reset_mock()
+
     #
     # Test Port Over-Riding
     #
@@ -1043,9 +1215,28 @@ def test_plugin_email_url_parsing(mock_smtp, mock_smtp_ssl):
     assert re.match(r'.*mode=ssl.*', obj.url()) is not None
     # No smtp= as the SMTP server is the same as the hostname in this case
     assert re.match(r'.*smtp=smtp.exmail.qq.com.*', obj.url()) is not None
-    # URL is assembled based on provided user
+    # URL is assembled based on provided user (:465 is dropped because it
+    # is a default port when using xyz.cn)
     assert re.match(
-        r'^mailtos://abc:password@xyz.cn:465/.*', obj.url()) is not None
+        r'^mailtos://abc:password@xyz.cn/.*', obj.url()) is not None
+
+    assert mock_smtp.call_count == 0
+    assert mock_smtp_ssl.call_count == 0
+    assert response.starttls.call_count == 0
+    assert obj.notify("test") is True
+    assert mock_smtp.call_count == 0
+    assert mock_smtp_ssl.call_count == 1
+    assert response.starttls.call_count == 0
+    assert response.login.call_count == 1
+    assert response.sendmail.call_count == 1
+
+    user, pw = response.login.call_args[0]
+    assert pw == 'password'
+    assert user == 'abc'
+
+    mock_smtp.reset_mock()
+    mock_smtp_ssl.reset_mock()
+    response.reset_mock()
 
     results = NotifyEmail.parse_url(
         "mailtos://abc:password@xyz.cn?"
@@ -1062,6 +1253,24 @@ def test_plugin_email_url_parsing(mock_smtp, mock_smtp_ssl):
     # No entries in the reply_to
     assert not obj.reply_to
 
+    assert mock_smtp.call_count == 0
+    assert mock_smtp_ssl.call_count == 0
+    assert response.starttls.call_count == 0
+    assert obj.notify("test") is True
+    assert mock_smtp.call_count == 0
+    assert mock_smtp_ssl.call_count == 1
+    assert response.starttls.call_count == 0
+    assert response.login.call_count == 1
+    assert response.sendmail.call_count == 1
+
+    user, pw = response.login.call_args[0]
+    assert pw == 'password'
+    assert user == 'abc'
+
+    mock_smtp.reset_mock()
+    mock_smtp_ssl.reset_mock()
+    response.reset_mock()
+
     #
     # Test Reply-To Email
     #
@@ -1079,6 +1288,24 @@ def test_plugin_email_url_parsing(mock_smtp, mock_smtp_ssl):
     # Test that our template over-ride worked
     assert 'reply=noreply%40example.com' in obj.url()
 
+    assert mock_smtp.call_count == 0
+    assert mock_smtp_ssl.call_count == 0
+    assert response.starttls.call_count == 0
+    assert obj.notify("test") is True
+    assert mock_smtp.call_count == 1
+    assert mock_smtp_ssl.call_count == 0
+    assert response.starttls.call_count == 1
+    assert response.login.call_count == 1
+    assert response.sendmail.call_count == 1
+
+    user, pw = response.login.call_args[0]
+    assert pw == 'pass'
+    assert user == 'user'
+
+    mock_smtp.reset_mock()
+    mock_smtp_ssl.reset_mock()
+    response.reset_mock()
+
     #
     # Test Reply-To Email with Name Inline
     #
@@ -1095,3 +1322,208 @@ def test_plugin_email_url_parsing(mock_smtp, mock_smtp_ssl):
         'mailtos://user:pass@example.com')
     # Test that our template over-ride worked
     assert 'reply=Chris+%3Cnoreply%40example.ca%3E' in obj.url()
+
+    assert mock_smtp.call_count == 0
+    assert mock_smtp_ssl.call_count == 0
+    assert response.starttls.call_count == 0
+    assert obj.notify("test") is True
+    assert mock_smtp.call_count == 1
+    assert mock_smtp_ssl.call_count == 0
+    assert response.starttls.call_count == 1
+    assert response.login.call_count == 1
+    assert response.sendmail.call_count == 1
+
+    user, pw = response.login.call_args[0]
+    assert pw == 'pass'
+    assert user == 'user'
+
+    mock_smtp.reset_mock()
+    mock_smtp_ssl.reset_mock()
+    response.reset_mock()
+
+    # Fast Mail Handling
+
+    # Test variations of username required to be an email address
+    # user@example.com; we also test an over-ride port on a template driven
+    # mailto:// entry
+    results = NotifyEmail.parse_url(
+        'mailto://fastmail.com/?to=hello@concordium-explorer.nl'
+        '&user=joe@mydomain.nl&pass=abc123'
+        '&from=Concordium Explorer Bot<bot@concordium-explorer.nl>')
+    assert isinstance(results, dict)
+    assert 'Concordium Explorer Bot<bot@concordium-explorer.nl>' == \
+        results['from_addr']
+    assert 'joe@mydomain.nl' == results['user']
+    assert results['port'] is None
+    assert 'fastmail.com' == results['host']
+    assert 'abc123' == results['password']
+    assert 'hello@concordium-explorer.nl' in results['targets']
+
+    obj = Apprise.instantiate(results, suppress_exceptions=False)
+    assert isinstance(obj, NotifyEmail) is True
+
+    assert mock_smtp.call_count == 0
+    assert mock_smtp_ssl.call_count == 0
+    assert obj.notify("test") is True
+    assert mock_smtp.call_count == 0
+    assert mock_smtp_ssl.call_count == 1
+    assert response.starttls.call_count == 0
+    assert response.login.call_count == 1
+    assert response.sendmail.call_count == 1
+    # Store our Sent Arguments
+    # Syntax is:
+    #  sendmail(from_addr, to_addrs, msg, mail_options=(), rcpt_options=())
+    #             [0]        [1]     [2]
+    _from = response.sendmail.call_args[0][0]
+    _to = response.sendmail.call_args[0][1]
+    _msg = response.sendmail.call_args[0][2]
+    assert _from == 'bot@concordium-explorer.nl'
+    assert isinstance(_to, list)
+    assert len(_to) == 1
+    assert _to[0] == 'hello@concordium-explorer.nl'
+    assert _msg.split('\n')[-3] == 'test'
+
+    user, pw = response.login.call_args[0]
+    assert pw == 'abc123'
+    assert user == 'joe@mydomain.nl'
+
+
+@mock.patch('smtplib.SMTP_SSL')
+@mock.patch('smtplib.SMTP')
+def test_plugin_email_plus_in_toemail(mock_smtp, mock_smtp_ssl):
+    """
+    NotifyEmail() support + in To Email address
+
+    """
+
+    response = mock.Mock()
+    mock_smtp_ssl.return_value = response
+    mock_smtp.return_value = response
+
+    # We want to test the case where a + is found in the To address; we want to
+    # ensure that it is supported
+    results = NotifyEmail.parse_url(
+        'mailtos://user:pass123@gmail.com'
+        '?to=Plus Support<test+notification@gmail.com>')
+    assert isinstance(results, dict)
+    assert 'user' == results['user']
+    assert 'gmail.com' == results['host']
+    assert 'pass123' == results['password']
+    assert results['port'] is None
+    assert 'Plus Support<test+notification@gmail.com>' in results['targets']
+
+    obj = Apprise.instantiate(results, suppress_exceptions=False)
+    assert isinstance(obj, NotifyEmail) is True
+
+    assert len(obj.targets) == 1
+    assert ('Plus Support', 'test+notification@gmail.com') in obj.targets
+
+    assert mock_smtp.call_count == 0
+    assert mock_smtp_ssl.call_count == 0
+    assert obj.notify("test") is True
+    assert mock_smtp.call_count == 1
+    assert mock_smtp_ssl.call_count == 0
+    assert response.starttls.call_count == 1
+    assert response.login.call_count == 1
+    assert response.sendmail.call_count == 1
+    # Store our Sent Arguments
+    # Syntax is:
+    #  sendmail(from_addr, to_addrs, msg, mail_options=(), rcpt_options=())
+    #             [0]        [1]     [2]
+    _from = response.sendmail.call_args[0][0]
+    _to = response.sendmail.call_args[0][1]
+    _msg = response.sendmail.call_args[0][2]
+    assert _from == 'user@gmail.com'
+    assert isinstance(_to, list)
+    assert len(_to) == 1
+    assert _to[0] == 'test+notification@gmail.com'
+    assert _msg.split('\n')[-3] == 'test'
+
+    mock_smtp.reset_mock()
+    mock_smtp_ssl.reset_mock()
+    response.reset_mock()
+
+    #
+    # Perform the same test where the To field jsut contains the + in the
+    # address
+    #
+    results = NotifyEmail.parse_url(
+        'mailtos://user:pass123@gmail.com'
+        '?to=test+notification@gmail.com')
+    assert isinstance(results, dict)
+    assert 'user' == results['user']
+    assert 'gmail.com' == results['host']
+    assert 'pass123' == results['password']
+    assert results['port'] is None
+    assert 'test+notification@gmail.com' in results['targets']
+
+    obj = Apprise.instantiate(results, suppress_exceptions=False)
+    assert isinstance(obj, NotifyEmail) is True
+
+    assert len(obj.targets) == 1
+    assert (False, 'test+notification@gmail.com') in obj.targets
+
+    assert mock_smtp.call_count == 0
+    assert mock_smtp_ssl.call_count == 0
+    assert obj.notify("test") is True
+    assert mock_smtp.call_count == 1
+    assert mock_smtp_ssl.call_count == 0
+    assert response.starttls.call_count == 1
+    assert response.login.call_count == 1
+    assert response.sendmail.call_count == 1
+    # Store our Sent Arguments
+    # Syntax is:
+    #  sendmail(from_addr, to_addrs, msg, mail_options=(), rcpt_options=())
+    #             [0]        [1]     [2]
+    _from = response.sendmail.call_args[0][0]
+    _to = response.sendmail.call_args[0][1]
+    _msg = response.sendmail.call_args[0][2]
+    assert _from == 'user@gmail.com'
+    assert isinstance(_to, list)
+    assert len(_to) == 1
+    assert _to[0] == 'test+notification@gmail.com'
+    assert _msg.split('\n')[-3] == 'test'
+
+    mock_smtp.reset_mock()
+    mock_smtp_ssl.reset_mock()
+    response.reset_mock()
+
+    #
+    # Perform the same test where the To field is in the URL itself
+    #
+    results = NotifyEmail.parse_url(
+        'mailtos://user:pass123@gmail.com'
+        '/test+notification@gmail.com')
+    assert isinstance(results, dict)
+    assert 'user' == results['user']
+    assert 'gmail.com' == results['host']
+    assert 'pass123' == results['password']
+    assert results['port'] is None
+    assert 'test+notification@gmail.com' in results['targets']
+
+    obj = Apprise.instantiate(results, suppress_exceptions=False)
+    assert isinstance(obj, NotifyEmail) is True
+
+    assert len(obj.targets) == 1
+    assert (False, 'test+notification@gmail.com') in obj.targets
+
+    assert mock_smtp.call_count == 0
+    assert mock_smtp_ssl.call_count == 0
+    assert obj.notify("test") is True
+    assert mock_smtp.call_count == 1
+    assert mock_smtp_ssl.call_count == 0
+    assert response.starttls.call_count == 1
+    assert response.login.call_count == 1
+    assert response.sendmail.call_count == 1
+    # Store our Sent Arguments
+    # Syntax is:
+    #  sendmail(from_addr, to_addrs, msg, mail_options=(), rcpt_options=())
+    #             [0]        [1]     [2]
+    _from = response.sendmail.call_args[0][0]
+    _to = response.sendmail.call_args[0][1]
+    _msg = response.sendmail.call_args[0][2]
+    assert _from == 'user@gmail.com'
+    assert isinstance(_to, list)
+    assert len(_to) == 1
+    assert _to[0] == 'test+notification@gmail.com'
+    assert _msg.split('\n')[-3] == 'test'
